;; Generated package description from futur.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "futur" "2.0.0.20260822.4" "Future/promise-based async library" '((emacs "27.1")) :commit "bcfc5c34b6a616d80bfbc41772a8f3a65e39b01a" :authors '(("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("Stefan Monnier" . "monnier@iro.umontreal.ca") :keywords '("concurrency" "async" "promises" "futures") :url "https://elpa.gnu.org/packages/futur.html")
